class AppSettingsBarWidget:
    type: str
    args: dict
    def __init__(self, **kwargs) -> None: ...

class AppSettingsBar:
    position: str
    size: int
    margin: list[int]
    widgets: list[AppSettingsBarWidget]
    def __init__(self, **kwargs) -> None: ...



from ebenezer.config.settings import AppSettings as AppSettings
from libqtile import widget

class FontIconTaskList(widget.TaskList):
    markup: bool
    def get_taskname(self, window): ...

def build_task_list_widget(settings: AppSettings, kwargs: dict): ...



from _typeshed import Incomplete
from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.widgets.formatter import burn_text as burn_text
from ebenezer.widgets.helpers.args import build_widget_args as build_widget_args
from libqtile.widget import Memory

class ColorizedMemoryWidget(Memory):
    high_color: Incomplete
    medium_color: Incomplete
    default_color: Incomplete
    threshold_medium: Incomplete
    threshold_high: Incomplete
    def __init__(self, **config) -> None: ...
    foreground: Incomplete
    def poll(self): ...

def build_memory_widget(settings: AppSettings, kwargs: dict): ...



import os
import sys

import setuptools_scm

sys.path.insert(0, os.path.abspath(".."))

# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = "Qtile Ebenezer"
copyright = "2024, William Sena"
author = "William Sena"
release = "0.1.4"

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.autosummary",
    "sphinx.ext.coverage",
    "sphinx.ext.graphviz",
    "sphinx.ext.todo",
    "sphinx.ext.viewcode",
]

templates_path = ["_templates"]
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store", "test"]


# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = "furo"
html_static_path = ["_static"]

html_use_index = True

version = setuptools_scm.get_version(root="..")
release = version



from ebenezer.core.command import run_shell_command as run_shell_command

TEMPLATE_NOTIFY: str
TEMPLATE_WITH_TITLE: str
TEMPLATE_NO_HISTORY: str

def push_notification(title: str, message: str): ...
def push_notification_progress(message: str, progress: int): ...
def push_notification_no_history(title: str, message: str): ...



from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.core.notify import push_notification_no_history as push_notification_no_history
from ebenezer.core.requests import request_retry as request_retry

OUTPUT_FILE: str
QUOTE_OUTPUT_FILE: str

def lock_screen(settings: AppSettings): ...
def run_i3_lock(settings: AppSettings): ...
def build_lock_screen_widget(settings: AppSettings): ...



class AppSettingsMonitoring:
    default_color: str
    high_color: str
    medium_color: str
    threshold_medium: int
    threshold_high: int
    burn: bool
    def __init__(self, **kwargs) -> None: ...



from _typeshed import Incomplete
from ebenezer.config.keybindings import AppSettingsKeyBinding as AppSettingsKeyBinding
from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.core.command import lazy_spawn as lazy_spawn
from ebenezer.widgets.backlight import setup_backlight_keys as setup_backlight_keys
from ebenezer.widgets.volume import setup_volume_keys as setup_volume_keys

ACTIONS: Incomplete

def build_keys(settings: AppSettings): ...



from _typeshed import Incomplete
from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.widgets.app_menu import build_app_menu_widget as build_app_menu_widget
from ebenezer.widgets.arrow import build_arrow_widget as build_arrow_widget
from ebenezer.widgets.battery import build_battery_widget as build_battery_widget
from ebenezer.widgets.clock import build_clock_widget as build_clock_widget
from ebenezer.widgets.cpu import build_cpu_widget as build_cpu_widget
from ebenezer.widgets.github import build_github_widget as build_github_widget
from ebenezer.widgets.group_box import build_group_box as build_group_box
from ebenezer.widgets.helpers.args import build_widget_args as build_widget_args
from ebenezer.widgets.hidden_tray import build_hidden_tray as build_hidden_tray
from ebenezer.widgets.layout import build_current_layout_widget as build_current_layout_widget
from ebenezer.widgets.memory import build_memory_widget as build_memory_widget
from ebenezer.widgets.notification import build_notification_widget as build_notification_widget
from ebenezer.widgets.powermenu import build_powermenu_widget as build_powermenu_widget
from ebenezer.widgets.spacer import build_spacer_widget as build_spacer_widget
from ebenezer.widgets.task_list import build_task_list_widget as build_task_list_widget
from ebenezer.widgets.thermal import build_thermal_widget as build_thermal_widget
from ebenezer.widgets.volume import build_volume_widget as build_volume_widget
from ebenezer.widgets.wallpaper import build_wallpaper_widget as build_wallpaper_widget
from ebenezer.widgets.weather import build_weather_widget as build_weather_widget
from ebenezer.widgets.window_name import build_window_name_widget as build_window_name_widget

def build_bar(settings: AppSettings): ...
def build_fallback_bar(settings: AppSettings): ...

WIDGETS: Incomplete



from _typeshed import Incomplete

app: Incomplete

def run_command(command: str) -> str: ...
def volume_level() -> None: ...
def volume_up() -> None: ...
def volume_down() -> None: ...
def mute_toggle() -> None: ...



from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.widgets.bar import build_bar as build_bar
from libqtile.config import Screen

def build_screen(settings: AppSettings) -> Screen: ...



from ebenezer.core.files import resolve_file_path as resolve_file_path

class AppSettingsEnvironment:
    modkey: str
    browser: str
    terminal: str
    wallpaper_dir: str
    wallpaper_timeout: int
    os_logo: str
    os_logo_icon: str
    os_logo_icon_color: str
    theme: str
    backlight_name: str
    weather_api_key: str
    city_id: str
    github_notifications_token: str
    def __init__(self, **kwargs: object) -> None: ...



class AppSettingsKeyBinding:
    name: str
    keys: list[str]
    action: str
    command: str
    def __init__(self, **kwargs) -> None: ...

def build_keybindings(items: list[dict]) -> list[AppSettingsKeyBinding]: ...



"""
files.py
--------

This module provides functions to resolve file paths with variable substitution.

Functions:
    resolve_file_path(raw_path: str) -> str:
        Resolves a file path by substituting predefined variables.
"""

from pathlib import Path
from string import Template

home = str(Path.home())
qtile_home = str(Path.joinpath(Path(home), ".config/qtile"))
theme_home = str(Path.joinpath(Path(qtile_home), "themes"))
rofi_home = str(Path.joinpath(Path(qtile_home), "ebenezer/rofi"))
scripts = str(Path.joinpath(Path(qtile_home), "ebenezer/scripts"))


def resolve_file_path(raw_path: str) -> str:
    """
    Resolves a file path by substituting predefined variables.

    Args:
        raw_path (str): The raw path template.

    Returns:
        str: The fully resolved and substituted path.
    """
    cmd_template = Template(raw_path)
    return cmd_template.safe_substitute(
        home=home,
        qtile_home=qtile_home,
        theme=theme_home,
        theme_home=theme_home,
        rofi_home=rofi_home,
        scripts=scripts,
    ).strip()



import subprocess
from ebenezer.core.files import resolve_file_path as resolve_file_path

DEFAULT_TIMEOUT: int

def build_shell_command(raw_cmd: str, **kwargs: object) -> str: ...
def run_shell_command(raw_cmd: str, timeout: float | None = 10, **kwargs: object) -> subprocess.CompletedProcess: ...
def run_shell_command_stdout(raw_cmd: str, **kwargs: object) -> subprocess.CompletedProcess: ...
def lazy_command(cmd: str | None, **kwargs: object): ...
def lazy_spawn(cmd: str, **kwargs: object): ...



from _typeshed import Incomplete
from ebenezer.core.dict import merge_dicts_recursive as merge_dicts_recursive
from ebenezer.core.yaml import read_yaml_file as read_yaml_file

TEST_CONFIG: str
TEST_COLOR_CONFIG: str

def load_raw_test_settings(): ...
def load_raw_settings(config_filepath: Incomplete | None = None, colors_filepath: Incomplete | None = None, applications_filepath: Incomplete | None = None, keybindings_filepath: Incomplete | None = None) -> dict: ...
def merge_yaml(file_paths, merged_data: dict = {}) -> dict: ...



from _typeshed import Incomplete
from ebenezer.config.settings import AppSettings as AppSettings, AppSettingsColors as AppSettingsColors
from ebenezer.core.dict import merge_dicts_recursive as merge_dicts_recursive
from ebenezer.core.files import resolve_file_path as resolve_file_path
from ebenezer.core.yaml import read_yaml_file as read_yaml_file

ROFI_TEMPLATES: Incomplete
DUNSTRC_HOME_PATH: str

def preload_colors(settings: AppSettings) -> AppSettings: ...



class AppSettingsLockScreen:
    command: str
    timeout: int
    font: str
    font_size: int
    quote_font_path: str
    quote_font_size: int
    joke_providers: str
    quote_foreground_color: str
    quote_text_color: str
    icanhazdad_joke_url: str
    reddit_joke_url: str
    blurtype: str
    def __init__(self, **kwargs) -> None: ...



from _typeshed import Incomplete
from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.core.command import build_shell_command as build_shell_command, run_shell_command as run_shell_command
from ebenezer.widgets.helpers.args import build_widget_args as build_widget_args
from libqtile.widget import base

class DunstWidget(base.ThreadPoolText):
    defaults: Incomplete
    count: int
    modal_confirm_cmd: Incomplete
    animated: Incomplete
    bells_index: int
    bells: Incomplete
    foreground_zero: Incomplete
    foreground_count: Incomplete
    def __init__(self, **config) -> None: ...
    foreground: Incomplete
    def poll(self): ...
    def get_bell_icon(self): ...
    def get_notification_count(self): ...
    def show_notifications(self) -> None: ...
    def clear_notifications(self) -> None: ...

def build_notification_widget(settings: AppSettings, kwargs: dict): ...



from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.core.command import lazy_command as lazy_command
from ebenezer.widgets.helpers.args import build_widget_args as build_widget_args

def build_wallpaper_widget(settings: AppSettings, kwargs: dict): ...



from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.core.command import run_shell_command as run_shell_command, run_shell_command_stdout as run_shell_command_stdout
from ebenezer.core.notify import push_notification as push_notification, push_notification_progress as push_notification_progress
from ebenezer.widgets.helpers.args import build_widget_args as build_widget_args

def build_volume_widget(settings: AppSettings, kwargs: dict): ...
def setup_volume_keys(settings: AppSettings): ...



from _typeshed import Incomplete
from ebenezer.config.applications import AppSettingsApplications as AppSettingsApplications
from ebenezer.config.bar import AppSettingsBar as AppSettingsBar
from ebenezer.config.colors import AppSettingsColors as AppSettingsColors
from ebenezer.config.environment import AppSettingsEnvironment as AppSettingsEnvironment
from ebenezer.config.fonts import AppSettingsFonts as AppSettingsFonts
from ebenezer.config.keybindings import AppSettingsKeyBinding as AppSettingsKeyBinding, build_keybindings as build_keybindings
from ebenezer.config.loader import load_raw_settings as load_raw_settings
from ebenezer.config.lock_screen import AppSettingsLockScreen as AppSettingsLockScreen
from ebenezer.config.monitoring import AppSettingsMonitoring as AppSettingsMonitoring
from ebenezer.core.files import qtile_home as qtile_home
from typing import Any

class AppSettings:
    applications: AppSettingsApplications
    bar: AppSettingsBar
    colors: AppSettingsColors
    commands: dict[str, str]
    environment: Incomplete
    floating: dict[str, list[str]]
    fonts: Incomplete
    groups: list[Any]
    groups_layout: dict[str, str]
    keybindings: list[AppSettingsKeyBinding]
    lock_screen: Incomplete
    monitoring: AppSettingsMonitoring
    startup: dict[str, str]
    def __init__(self, **kwargs) -> None: ...

def load_settings_by_files(config_filepath: Incomplete | None = None, colors_filepath: Incomplete | None = None, applications_filepath: Incomplete | None = None) -> AppSettings: ...
def load_settings(raw_settings: dict) -> AppSettings: ...



from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.core.command import run_shell_command as run_shell_command

DEFAULT_TIMEOUT: int

def run_startup_once(settings: AppSettings): ...



from _typeshed import Incomplete

app: Incomplete

def run_command(command: str) -> str: ...
def backlight_level() -> None: ...
def backlight_up() -> None: ...
def backlight_down() -> None: ...
def do_backlight_level() -> str: ...
def do_backlight_up() -> None: ...
def do_backlight_down() -> None: ...



class AppSettingsColors:
    raw: dict
    theme: str | None
    fg_normal: str
    fg_focus: str
    fg_urgent: str
    bg_normal: str
    bg_focus: str
    bg_urgent: str
    bg_systray: str
    bg_selected: str
    fg_blue: str
    fg_light_blue: str
    fg_yellow: str
    fg_red: str
    fg_orange: str
    fg_purple: str
    fg_green: str
    fg_gray: str
    fg_black: str
    fg_white: str
    fg_selected: str
    bg_topbar: str
    bg_topbar_selected: str
    bg_topbar_arrow: str
    border_color_normal: str
    border_color_active: str
    border_color_marked: str
    titlebar_bg_focus: str
    titlebar_bg_normal: str
    taglist_bg_focus: str
    group_focus: str
    group_normal: str
    lock_screen_blank_color: str
    lock_screen_clear_color: str
    lock_screen_default_color: str
    lock_screen_key_color: str
    lock_screen_text_color: str
    lock_screen_wrong_color: str
    lock_screen_verifying_color: str
    lock_screen_quote_foreground_color: str
    lock_screen_quote_text_color: str
    rofi_background: str
    rofi_background_alt: str
    rofi_foreground: str
    rofi_selected: str
    rofi_active: str
    rofi_urgent: str
    rofi_border: str
    rofi_border_alt: str
    def __init__(self, **kwargs) -> None: ...
    def get_color(self, color_name: str) -> str: ...



class AppSettingsFonts:
    font: str
    font_regular: str
    font_light: str
    font_strong: str
    font_strong_bold: str
    font_size: int
    font_icon: str
    font_icon_size: int
    font_arrow: str
    font_arrow_size: int
    rofi_font: str
    rofi_font_size: int
    font_notification: str
    font_notification_size: int
    def __init__(self, **kwargs) -> None: ...



from _typeshed import Incomplete
from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.widgets.helpers.args import build_widget_args as build_widget_args
from libqtile.widget import base

def get_layout_icon(layout_name): ...

ICONS: Incomplete

class CurrentLayoutFontIcon(base._TextBox):
    def __init__(self, width=..., **config) -> None: ...
    text: Incomplete
    def hook_response(self, layout, group) -> None: ...
    def setup_hooks(self) -> None: ...
    def remove_hooks(self) -> None: ...
    def finalize(self) -> None: ...

def build_current_layout_widget(settings: AppSettings, kwargs: dict): ...



from _typeshed import Incomplete
from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.core.command import build_shell_command as build_shell_command
from ebenezer.core.requests import request_retry as request_retry
from ebenezer.widgets.helpers.args import build_widget_args as build_widget_args
from libqtile.widget import base

class GitHubNotifications(base.ThreadPoolText):
    orientations: Incomplete
    defaults: Incomplete
    settings: Incomplete
    icon: Incomplete
    token: Incomplete
    def __init__(self, **config) -> None: ...
    def poll(self): ...

def build_github_widget(settings: AppSettings, kwargs: dict): ...



from ebenezer.config.settings import AppSettings as AppSettings
from ebenezer.widgets.backlight import build_backlight_widget as build_backlight_widget
from ebenezer.widgets.helpers.args import build_widget_args as build_widget_args
from ebenezer.widgets.wallpaper import build_wallpaper_widget as build_wallpaper_widget

def build_hidden_tray(settings: AppSettings, kwargs: dict): ...
